@@ -68,6 +68,7 @@
 
 #define KEY_LIVE_HIDDEN_WINDOWS "/apps/mutter/general/live_hidden_windows"
 #define KEY_WORKSPACES_ONLY_ON_PRIMARY "/apps/mutter/general/workspaces_only_on_primary"
+#define KEY_DRAGGABLE_BORDER_WIDTH "/apps/mutter/general/draggable_border_width"
 
 #define KEY_NO_TAB_POPUP "/apps/metacity/general/no_tab_popup"
 
@@ -100,6 +101,7 @@ static gboolean gnome_accessibility = FALSE;
 static gboolean gnome_animations = TRUE;
 static char *cursor_theme = NULL;
 static int   cursor_size = 24;
+static int   draggable_border_width = 10;
 static gboolean resize_with_right_button = FALSE;
 static gboolean edge_tiling = FALSE;
 static gboolean force_fullscreen = TRUE;
@@ -493,6 +495,11 @@ static MetaIntPreference preferences_int[] =
       &cursor_size,
       1, 128, 24,
     },
+    { "/apps/mutter/general/draggable_border_width",
+      META_PREF_DRAGGABLE_BORDER_WIDTH,
+      &draggable_border_width,
+      0, 64, 10,
+    },
     { NULL, 0, NULL, 0, 0, 0, },
   };
 
@@ -1679,6 +1686,7 @@ button_layout_handler (MetaPreference pref,
   if (string_value)
     sides = g_strsplit (string_value, ":", 2);
 
+  i = 0;
   if (sides != NULL && sides[0] != NULL)
     {
       char **buttons;
@@ -1733,12 +1741,13 @@ button_layout_handler (MetaPreference pref,
           ++b;
         }
 
-      new_layout.left_buttons[i] = META_BUTTON_FUNCTION_LAST;
-      new_layout.left_buttons_has_spacer[i] = FALSE;
-      
       g_strfreev (buttons);
     }
 
+  new_layout.left_buttons[i] = META_BUTTON_FUNCTION_LAST;
+  new_layout.left_buttons_has_spacer[i] = FALSE;
+
+  i = 0;
   if (sides != NULL && sides[0] != NULL && sides[1] != NULL)
     {
       char **buttons;
@@ -1792,12 +1801,12 @@ button_layout_handler (MetaPreference pref,
           ++b;
         }
 
-      new_layout.right_buttons[i] = META_BUTTON_FUNCTION_LAST;
-      new_layout.right_buttons_has_spacer[i] = FALSE;
-      
       g_strfreev (buttons);
     }
 
+  new_layout.right_buttons[i] = META_BUTTON_FUNCTION_LAST;
+  new_layout.right_buttons_has_spacer[i] = FALSE;
+
   g_strfreev (sides);
   
   /* Invert the button layout for RTL languages */
@@ -1985,6 +1994,9 @@ meta_preference_to_string (MetaPreference pref)
 
     case META_PREF_NO_TAB_POPUP:
       return "NO_TAB_POPUP";
+
+    case META_PREF_DRAGGABLE_BORDER_WIDTH:
+      return "DRAGGABLE_BORDER_WIDTH";
     }
 
   return "(unknown)";
@@ -3038,6 +3050,12 @@ meta_prefs_set_no_tab_popup (gboolean whether)
 #endif
 }
 
+int
+meta_prefs_get_draggable_border_width (void)
+{
+  return draggable_border_width;
+}
+
 #ifndef HAVE_GCONF
 static void
 init_button_layout(void)
